#
# spec file for package q5go
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           q5go
Version:        2.1.3
Release:        1.10
Summary:        A Go board including an editor and analysis frontend
License:        GPL-2.0-or-later
Group:          Amusements/Games/Board/Other
URL:            https://github.com/bernds/q5go
Source0:        https://github.com/bernds/%{name}/archive/%{name}-%{version}.tar.gz
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
# Required for https://doc.qt.io/qt-5/qmetaobject.html#invokeMethod-4
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)

%description
q5Go is a tool for Go players which performs the following functions:

 * SGF editor
 * Analysis frontend for Leela Zero (or compatible engines)
 * GTP interface
 * IGS client
 * Export to a variety of formats

%prep
%autosetup -p1 -n q5Go-q5go-%{version}

%build
pushd src
%qmake5 q5go.pro

%make_jobs
popd

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/applications
mkdir -p %{buildroot}%{_datadir}/pixmaps
mkdir -p %{buildroot}%{_datadir}/q5go/translations

pushd src
install -m 0755 q5go %{buildroot}%{_bindir}/

# install translations
install -m 0644 translations/*.qm %{buildroot}%{_datadir}/q5go/translations/

# q5go doesn't have a highres icon
install -m 0644 images/clientwindow/Bowl.png %{buildroot}%{_datadir}/pixmaps/q5go.png

%suse_update_desktop_file -c q5Go q5Go "Go client" q5go q5go "Qt;Game;BoardGame;"
popd

%files
%license COPYING
%doc AUTHORS ChangeLog README.md
%{_bindir}/q5go
%{_datadir}/applications/q5Go.desktop
%{_datadir}/pixmaps/q5go.png
%{_datadir}/q5go

%changelog
* Mon May  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.1.3
  * Added autoplay feature for viewing SGF files
  * More support for KataGo's ruleset feature
* Fri Jul 23 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.1.2
  * fix an issue when saving SGF files in locales where a comma
    is used instead of a decimal point.
* Mon Apr 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.1.1
  * A number of crashes in odd situations were fixed
  * It is now possible to copy/paste positions in Edit mode.
  * The batch analysis dialog has a new button to enqueue
    an entire directory of SGF files.
  * Engine games now allow board sizes up to 52.
* Mon Oct 26 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.0
  * Pattern search is now available
  * atabase load times are reduced, and threading was added
    so that the user interface remains responsive.
  * Multiple online games can now be observed in a single
    window with clickable previews to switch between them.
  * There is a new "Tip of the day" dialog on startup, which
    displays features that are maybe not easily discoverable.
  * Several new high resolution wood textures for the board
    to choose from.
  * When playing engines that are capable of analysis, the
    evaluation is now collected during the game and can be
    displayed live.
  * Engine configuration now allows engines to be
    unrestricted in board size and komi
  * Some GTP bugs were fixed, which may improve compatibility
    with certain engines.
  * Window titles can now be overriden in the settings,
    which should help with streaming setups.
  * Performance improvements for the screen updates should
    now make it feasible to turn off quiet mode when online
  * There is a new option to highlight the user's own chat
    messages
- Drop 0001-Add-missing-includes.patch. Fixed upstream.
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.1.1. Bugfix release:
  * Fix loading and saving large board sizes
  * There is now a tool to manage and remove the information
    added by engine analysis from a given SGF file
  * It is now possible to save all variations in a file
    into separate files.
  * It is possible to choose a path for autosaving online games.
* Sat Apr 25 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.1
  * Performance improvements when loading and editing
    very large SGF files.
  * q5go can now detect when an observed game on IGS is
    adjourned and restarted and follow it in the same window.
    This requires the server to be set to non-quiet mode.
  * When playing an engine, there is now a "Play again" button.
  * In an online match with Canadian time, time warnings can
    now be enabled for remaining average time, not just
    remaining total time.
  * In an online match, remaining seconds in low time situations
    can now be shown on the opponent's last placed stone.
  * Added a "Go terminology" SGF to the tutorials.
  * The greeter window now has a hint to choose "Play online"
    for a full set of menus.
  * The program is more helpful when detecting a broken SGF
    written by Jago.
  * Added more helpful error messages when editing servers
    in the preferences.
  * Score evaluations are now shown in the board window when
    analysis is on.
  * Added a feature to visualize connected stones by drawing thick
    lines between them. May be helpful for beginners.
  * GTP support was extended to support board sizes > 25, for KataGo.
* Tue Nov  5 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.0
  * A greeter dialog was added, similar to the ones used by cgoban or gGo.
  * There is now a "Learn Go" button that brings up beginner tutorials
    in a slideshow view.
  * Engine configuration in the preferences is a little more friendly.
  * Edit mode works differently. Depending on the situation, an edited
    position can be appended to or inserted before the current node,
    or replace a previous edit.
  * The board window now has menu items for undo/redo.
  * When playing on IGS, the comments box now allows chatting even after
    a match has completed, making it unnecessary to find the opponent's talk tab.
  * Corrected a bug when parsing nmatch preferences on IGS.
- Drop patches, now upstream:
  * 0001-Disable-game-tree-header-with-Qt-5.10.patch
  * 0001-Remove-PlaceholderText-colorroles-which-were-added-b.patch
* Sun Oct 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add patches to build with older Qt versions:
  * 0001-Disable-game-tree-header-with-Qt-5.10.patch
  * 0001-Remove-PlaceholderText-colorroles-which-were-added-b.patch
  * 0001-Add-missing-includes.patch
* Thu Sep 19 2019 Ferdinand Thiessen <rpm@fthiessen.de>
- Add correct QT5Core requirement, as q5go requires some specific
  API.
* Sun Sep  8 2019 Jan Engelhardt <jengelh@inai.de>
- Update description: use list bullets.
* Wed Sep  4 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add q5go, a go board game. (boo#1148398)
